"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TimedState = void 0;
class TimedState {
    constructor(initState, reducer) {
        this.initState = initState;
        this.reducer = reducer;
        this.itemLimit = 100;
        this.timeLimit = 5000;
        this.onFlush = () => { };
        this.length = 0;
        this.state = this.initState();
        this.timer = null;
    }
    push(item) {
        this.length++;
        this.state = this.reducer(this.state, item);
        if (this.length >= this.itemLimit) {
            this.flush();
            return;
        }
        if (!this.timer) {
            this.timer = setTimeout(() => {
                this.flush();
            }, this.timeLimit);
        }
    }
    flush() {
        const { state, length } = this;
        this.state = this.initState();
        this.length = 0;
        if (this.timer)
            clearTimeout(this.timer);
        if (length) {
            this.timer = null;
            try {
                this.onFlush(state);
            }
            catch (error) {
                console.error('TimedState', error);
            }
        }
        return state;
    }
}
exports.TimedState = TimedState;
